pycolombianizer package
=======================

Submodules
----------

pycolombianizer.cli module
--------------------------

.. automodule:: pycolombianizer.cli
    :members:
    :undoc-members:
    :show-inheritance:

pycolombianizer.pycolombianizer module
--------------------------------------

.. automodule:: pycolombianizer.pycolombianizer
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pycolombianizer
    :members:
    :undoc-members:
    :show-inheritance:
